@@ -120,7 +120,7 @@ class HbmpView(object):
         for row in data:
             html += "<tr>"
             for item in row:
-                item = item.split(':')
+                item = item.split('>')
                 #assert len(item) == 1 or len(item) == 2, "Bad cell format"
                 if len(item) == 2:
                     item, link = item
@@ -129,18 +129,25 @@ class HbmpView(object):
                     link = None
 
                 if not link:
-                    html += "<td class='%s' height='%s' width='%s' style='padding: 0; border: 1px solid black; background-color: %s'>" % (
+                    html += """
+<td class='%s' height='%s' width='%s' 
+    style='padding: 0; border: 1px solid black; background-color: %s'>
+""" % (
                         item,
                         self.pixelheight(req),
                         self.pixelwidth(req),
                         item)
                 else:
-                    html += "<td href='%s' class='%s' height='%s' width='%s' style='padding: 0; border: 1px solid black; background-color: %s'>" % (
+                    html += """
+<td href='%s' class='%s' height='%s' width='%s' 
+    style='padding: 0; border: 1px solid black; background-color: %s'>
+""" % (
                         link,
                         item,
                         self.pixelheight(req),
                         self.pixelwidth(req),
                         item)
+                    html += "<center><a href='%s'>&nbsp;</a></center>" % link
 
                 html += "&nbsp;</td>"
 
